﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Controls.Charts;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.Controls;
using System.Diagnostics;

namespace AxisMinMaxValueBinding
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        ChartViewModel vm = new ChartViewModel();
        public MainWindow()
        {
            InitializeComponent();
            DataContext = vm;
        }

        private void xamDataChart1_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            if (e.OriginalSource is Rectangle)
            {                
                DataContext context = (e.OriginalSource as Rectangle).DataContext as DataContext;
                if (context != null)
                {

                    ScalerParams sParams = new ScalerParams(xamDataChart1.WindowRect, new Rect(0, 0, xamDataChart1.ActualWidth, xamDataChart1.ActualHeight), false);
                    int value = (int)Math.Floor(xAxis.GetUnscaledValue(e.GetPosition(context.Series).X, sParams));
                    
                    RecordFilter filter = new RecordFilter
                    {
                        FieldName = "Date"
                    };
                    filter.Conditions.Add(new ComparisonCondition(ComparisonOperator.Equals, vm.Data.ElementAt(value).Date));
                    xamDataGrid1.DefaultFieldLayout.RecordFilters.Clear();
                    xamDataGrid1.DefaultFieldLayout.RecordFilters.Add(filter);
                }
            }
        }
    }

    public class ChartViewModel
    {
        public ChartViewModel()
        {
            Data = ChartData.GenerateData(20);
            YMin = Math.Floor(Math.Min(Data.Min(i => i.Value1), Math.Min(Data.Min(i => i.Value2), Data.Min(i => i.Value3)))) - 40;
            YMax = Math.Ceiling(Math.Max(Data.Max(i => i.Value1), Math.Max(Data.Max(i => i.Value2), Data.Max(i => i.Value3)))) + 40;

        }

        public ObservableCollection<ChartData> Data { get; set; }
        public double YMin { get; set; }
        public double YMax { get; set; }

    }

    public class ChartData
    {
        public DateTime Date { get; set; }
        public int Index { get; set; }
        public double Value1 { get; set; }
        public double Value2 { get; set; }
        public double Value3 { get; set; }

        public static ObservableCollection<ChartData> GenerateData(int count)
        {
            ObservableCollection<ChartData> data = new ObservableCollection<ChartData>();

            Random r = new Random();

            ChartData data0 = new ChartData
            {
                Date = DateTime.Now.Date,
                Index = 0,
                Value1 = r.Next(20, 40),
                Value2 = r.Next(250, 300),
                Value3 = r.Next(-40, -20),
            };

            data.Add(data0);

            for (int i = 1; i < count; i++)
            {
                ChartData dat = new ChartData
                {
                    Date = DateTime.Now.AddMonths(i).Date,
                    Index = i,
                };

                if (r.NextDouble() > .5)
                {
                    dat.Value1 = data[i - 1].Value1 + r.NextDouble();
                    dat.Value2 = data[i - 1].Value2 + r.NextDouble();
                    dat.Value3 = data[i - 1].Value3 + r.NextDouble();
                }
                else
                {
                    dat.Value1 = data[i - 1].Value1 - r.NextDouble();
                    dat.Value2 = data[i - 1].Value2 - r.NextDouble();
                    dat.Value3 = data[i - 1].Value3 - r.NextDouble();
                }

                data.Add(dat);
            }

            return data;
        }
    }
}
